==> korweblog-1.5.9.tar.gz: korweblog-1.5.9/admin/lang/utf8.php <==
<?
define("_TOP5_DESC","가장 많이 읽은 글 5개");
define("_HOT5_DESC","가장 답장이 많은 글 5개");
define("_LASTC5_DESC","마지막으로 답장이 붙은글 5개");
define("_STORY_EXT","본문 관련 링크 설정");
define("_STORY_LINK_INDEX","본문 관련 링크 인덱스");
define("_STORY_LINK_INDEX_ADD","인덱스 추가하기");
define("_STORY_LINK_INDEX_KILL","인덱스를 지우면 해당 본문의 관련 링크도 삭제 됩니다.");

define("_LINK_ANYONE","링크 등록 가능 (관리자 확인필요)");
define("_LINK_ONLYADMIN","관리자만 등록 가능");
define("_LINK_FREE","사용자가 자유롭게 링크 등록 가능");
# logs.php
define("_LOGS_NOTHING","내용이 없습니다");
define("_LOGS_RESET","내용 비우기");

# layout.php
define("_LAYOUT_EDITOR","레이아웃 편집기: ");
define("_LAYOUT_VIEW","보기/읽기");
define("_LAYOUT_KILL","삭제");
define("_LAYOUT_ADD","추가/수정");
define("_LAYOUT_AUTHOR","작성자");
define("_LAYOUT_DESC","설명");
define("_LAYOUT_BG","백그라운드 이미지");
define("_LAYOUT_LOGO","로고 이미지");
define("_LAYOUT_FONT","폰트 설정");
define("_LAYOUT_WIDTH","페이지 폭");

define("_LAYOUT_TITLE_COLOR","본문 제목");
define("_LAYOUT_BLOCK_WIDTH","블럭 폭");
define("_LAYOUT_BLOCK_ALIGN","기본 블럭 정렬");
define("_LAYOUT_THEME","테마 / 템플레이트");
define("_LAYOUT_B_LEFT","왼쪽 블럭");
define("_LAYOUT_B_RIGHT","오른쪽 블럭");
define("_LAYOUT_ADDED","레이아웃 파일이 수정되었습니다.");
define("_NOTKILL","삭제하려는 테마가 현재 기본테마로 설정되어 있으므로 삭제할수 없습니다.");

# for Log Messages
define("_UPDATE_STORY","본문 수정");
define("_REPOST_STORY","본문 재등록");
define("_UPDATE_BLOCK","블럭 수정");
define("_UPDATE_REPLY","답장 수정");
define("_UPDATE_TOPIC","분류 수정");
define("_ADD_TOPIC","새분류 생성");
define("_ADD_POLL","투표 생성");
define("_ADD_BLOCK","블럭 추가");
define("_UPDATE_POLL","투표 수정");
define("_UPDATE_CATE","링크 분류 수정");
define("_LOG_RESET","로그 지움");
define("_UPDATE_LAYOUT","레이아웃 수정");
define("_DELETE_LAYOUT","레이아웃 삭제");
define("_UPDATE_SITE","사이트 기본 설정 수정");
define("_UPDATE_STORY_CONF","본문 설정 수정");
define("_UPDATE_REPLY_CONF","답장 설정 수정");
define("_UPDATE_EXT_CONF","확장 기능 수정");
define("_DELETE_ITEM","삭제");
define("_UNABLE_DEL","삭제시 에러 발생");
define("_DEL_POLL","투표 삭제");
define("_DEL_TOPIC","분류 삭제");
define("_DEL_CATE","링크 분류 삭제");

# for Additional Control Page
define("_SHOW_PTIME","페이지 처리 시간 표시");
define("_SHOW_NUM","각 분류의 글갯수 표시");
define("_CATCH_REPLY","모든 답장을 관리자가 이메일로 받아보기");
define("_FORM_WRAP","입력폼의 WRAP 설정");
define("_QP_ENCODE","발송되는 메일의 본문을 자체 QP 인코딩함");
define("_USE_THEME","사용자 테마 블럭");
define("_THEMES","사용자가 고를수 있는 테마 선택");
define("_ANTI_SPAM","스팸 방지 기능");
define("_ANTI_SPAM2","글쓰기 제한 IP");
define("_ANTI_IP","접근 제한 IP");
define("_BLOCK_IP_LIST","접근 제한 IP 목록");
define("_SPAM_LIST","스팸 문자열 목록");
define("_BLOCK_LIST","글쓰기 제한 IP 목록");
define("_SHOW_CONTACT","연락처 링크 표시");
define("_CONT_ADD_TXT","글 올리기 페이지에 보여줄 글 (html 가능)");
define("_LOGIN_AD_TXT","익명 사용자의 로그인 박스에 표시될 글 (html 가능)");
define("_TOTAL_COUNT_IN_TOPIC","분류 블럭에 전체 본문,답장수 표시");
define("_REPLY_HTML_PARSE_LEVEL","답장의 html 파싱 레벨");
define("_REPLY_PAGES","답장 표시때 페이지로 나눔");
define("_FILE_CACHE","RDF,URL,INCLUDE 등의 캐쉬를 파일로 처리");
define("_SHOW_IP","본문/답장에 글쓴이 IP 주소를 표시");
define("_ENABLE_BUTTON","본문 하단에 다음/이전글 링크 표시");
define("_ENABLE_DAY","이전글 블럭에 요일/날짜 표시");
define("_REREPLY","답장을 부모 답장의 글쓴이에게 메일로 보내기");
define("_FEATURE_TITLE","특집기사 블럭의 제목");
define("_UC_SCORE","로그인 사용자가 점수 조절 가능(답장 작성시)");

# topics.php
define("_TOPIC_IMAGE","이미지");
define("_TOPIC_TITLE","제목");
define("_TOPIC_ALTTAG","ALT 태그");
define("_TOPIC_RULE","제한");
define("_TOPIC_KILL","분류가 삭제되면 관련 본문 / 답장도 삭제 됩니다.");
define("_TOPIC_ADD","새 분류 추가");
define("_TOPIC_IMG_NULL","비어있으면 사용하지 않습니다.");
define("_TOPIC_NO_POST","글 올리기 불가");
define("_TOPIC_NO_COMMENT","답장 불가");

# http referer
define("_REFER_LIMIT","기록 제한");
define("_REFER_LIMIT_NO","무제한");
define("_SHOW_ALL","모두 보기");

# browser, os recored
define("_COUNTER","브라우저/OS 기록 (통계)");
define("_TIME_COUNTER","시간별 접속 통계");
define("_COUNT_INIT","초기화 하기");

# menu block
define("_MENU_BLOCK","주 메뉴 블럭 위치");

# session
define("_SESSION","세션 사용 (온라인 접속자 확인 기능)");
define("_SESSION_TMOUT","<font size=\"-1\">시스템을 다음 시간동안 사용하지 않으면 접속하지 않은 것으로 판단: ");
define("_SESSION_MIN","분</font>");
define("_ONLY_SESSION","(<a href=\"user-ext.php\">세션 사용</a>이 켜져 있을 경우에만 작동합니다.)");

# private msg
define("_PRIVATE_MSG","사용자 개인 쪽지");
define("_PRIV_MSG_LIMIT","최대 쪽지 수 제한");

# user
define("_LEVEL","권한");
define("_NORMAL_USER","일반 사용자");
define("_MODERATOR","중재자");
define("_SCORE_MODERATOR","점수 중재자");
define("_TOTAL","전체");
define("_USER_ADMIN","사용자 관리");
define("_USER_ADD","등록");
define("_USER_FIND","찾기");
define("_USER_EDIT","수정");
define("_USER_KILL","삭제");
define("_SENDMAIL","등록후 사용자에게 이메일 보냄");
define("_UPDATED_USERDB","사용자 정보를 변경 했습니다.");
define("_USER_ADDED","사용자를 등록 했습니다.");
define("_USER_DELETED","사용자를 삭제 했습니다.");

# submit log
define("_UPDATED","수정됨");

define("_MORECONFIG","추가");

# user-ext
define("_REGIST_METHOD","사용자 등록시 이메일 주소 유효성 확인");
define("_USER_IMG","사용자 홈의 이미지");
define("_COOKIE_TIME","사용자 로그인 쿠키 유효 기간");
define("_DAY","일");

define("_STORY_WATING","예약된 글");
define("_NO_PROGRAM_STORY","프로그램된 글이 없습니다.");
define("_AUTO_STORY","예약 포스팅");
define("_STORY_PROGRAM","이 글을 지정된 시간에 포스팅");
define("_PROGRAM_SAVED","성공적으로 저장 되었습니다.");
define("_CURRENT_TIME","현재 시간");
define("_YEAR","년");
define("_UMONTH","월");
define("_HOUR","시");
define("_MINUTE","분");
define("_POSTING_TIME","예약 시간");
define("_STORY_PROGRAM_EDITED","변경 사항이 저장 되었습니다.");
define("_STORY_PROGRAM_DELETED","글을 삭제 했습니다.");

define("_BMARK_LIMIT","책갈피 갯수 제한");

# admin_msg.php
define("_ADMIN_MSG","관리자 알림 메세지");
define("_ADMIN_MSG_EDIT","수정");
define("_ADMIN_MSG_ADD","추가");
define("_DISPLAY","표시 여부");
define("_ACTIVE","표시");
define("_INACTIVE","끔");
define("_DISPLAY_TYPE","표시 방법");
define("_EXPIRE","만기");
define("_CONTENT","내용");

define("_COPYRIGHT","저작권");
define("_NOLOGIN_USER","로그인 사용자 기능 사용하지 않음");

# sql.php
define("_PHP_INFO","PHP 정보 보기");
define("_SQL_RUNTIME","런타임 정보 보기");
define("_SQL_SYSTEM_VAR","시스템 변수 보기");
define("_SQL_PROCESS","프로세스 보기");
define("_SQL_CHECK_TABLE","테이블 확인");
define("_SQL_REPAIR_TABLE","테이블 복구");
define("_SQL_OPTIMIZE_TABLE","테이블 옵티마이즈");
define("_SQL_BACKUP_TABLE","데이터베이스 백업");
define("_SQL_DOCUMENT","도움말");
define("_SQL_ADMIN","데이터베이스 관리");

# navigator.php
define("_NAVIGATOR","메뉴 설정");
define("_NAVIG_TOP","상단 링크");
define("_NAVIG_BLOCK","주 메뉴 블럭");
define("_NAVIG_MOVE","이동");
define("_NAVIG_NAME","링크");
define("_NAVIG_ORDER","정렬");
define("_NAVIG_ADD","외부 링크 추가");
define("_NAVIG_EDIT","외부 링크 수정");
define("_NAVIG_DISPLAY_NAME","링크 이름");
define("_NAVIG_URL","Url");

# faq.php
define("_NEW_FAQ","새 FAQ 만들기");
define("_FAQ_TITLE","FAQ 제목");
define("_ADD_QA","질문/답변 추가하기");
define("_EDIT_QA","질문/답변 수정하기");
define("_EDIT_FAQ","FAQ 제목 수정");

# htmltag.php
define("_HTML_OPTION","HTML 태그 설정");
define("_HTML_OPTION1","최소한 한개 이상의 태그를 선택해야 합니다.");

# config-story.php
define("_HTML_PARSE_LEVEL","기본 HTML 파싱 레벨");
define("_RDF_USE","RDF 파일 사용 여부");
define("_MAILING_USE","메일링 리스트 사용");
define("_USER_PARSE","사용자가 파싱 레벨 결정");
define("_EXPORT_RDF_NOW","RSS 파일 다시 만들기");
define("_EXPORT_RDF_NOW1","RSS 파일을 만들었습니다.");
define("_THUMBNAIL","썸네일 만들기");
define("_IMAGICK","Imagick 프로그램의 완전한 경로 (보통 /usr/bin/convert)");
define("_MAX_PIC_PIXEL","첨부된 이미지 파일(jpg,gif,png)의 크기가 다음에 지정한 넓이 또는 높이(픽셀 단위) 보다 크면 썸네일을 만듭니다.");
define("_THUMB_SIZE","썸네일의 크기를 지정 합니다 (넓이, 픽셀 단위)");

# polls.php
define("_POLL_QUES","질문");
define("_POLL_ADD","투표 추가하기");
define("_POLL_DISP","표시 위치");
define("_POLL_EXPIRE","쿠키 만료일");
define("_POLL_ANSWER","답변");

# random_link.php
define("_RANDOM_LINK_ADD","링크 추가");
define("_RANDOM_LINK_EDIT","링크 수정");
define("_RANDOM_LINK_TITLE","링크 이름");
define("_RANDOM_LINK_NUMS","한번에 표시할 링크 갯수");
define("_RANDOM_LINK_HEAD","랜덤 링크 블럭 제목");
define("_RANDOM_LINK_SOURCE","링크 소스");
define("_RLINK_PREF1","직접 입력");
define("_RLINK_PREF2","링크 페이지에서");
define("_RLINK_PREF3","본문 관련 링크에서");

# random_button.php
define("_RANDOM_BUTTON_ADD","버튼 추가");
define("_RANDOM_BUTTON_EDIT","버튼 수정");
define("_RANDOM_BUTTON_ALT","Alt 문자");
define("_RANDOM_BUTTON_NUMS","한번에 표시할 버튼 갯수");
define("_RANDOM_BUTTON_HEAD","랜덤 버튼 블럭 제목");

# banners.php
define("_BANNER","배너");
define("_BANNER_LOCATION","배너 표시 위치");
define("_BANNER_LOCATION_DESC","각 테마 템플레이트 파일의 \"header.tmpl\", 또는 \"footer.tmpl\" 파일에 \"\$banner\" 변수를 추가해야 합니다.");
define("_BANNER_ALT","ALT 문자");
define("_BANNER_ADD","배너 추가");
define("_BANNER_EDIT","배너 수정");

# blocks.php
define("_BLOCK_STORY_ONLY","메인 페이지에만 표시");
define("_BLOCK_RDF_SUPP","RSS/RDF 포맷을 지원합니다.");
define("_BLOCK_INCLUDE","URL 또는 PATH");
define("_BLOCK_CACHE","캐쉬 설정");
define("_BLOCK_CACHE_DESC","분 / 0은 캐쉬 안함");
define("_NOT_URL","Url 또는 파일을 읽을 수 없습니다");
define("_MAX_ITEMS","최대 링크 갯수");

# config-site.php
define("_UNIQUEKEY","보안 열쇠");
define("_KEYDESC","Korweblog를 처음 설치했다면 반듯이 수정하여야 합니다.");

# config-new.php
define("_STORY_LST","익명 사용자의 답장 읽기를 제한할 본문 Rid");

# user-mail.php
define("_ALL","전체");
define("_MAIL_SEND","보냄");
define("_GROUP_MAIL","그룹 메일 보내기");
define("_GROUP","사용자 그룹");
define("_SENDMAIL_WARN","사용자가 많은 경우 시간이 많이 소요 될 수 있습니다. \"보냄\" 버튼을 누르시고 다음 화면이 나타날때 까지 기다리셔야 합니다. 버튼을 여러번 누르거나 브라우저를 종료하면 메일 전송에 실패 할 수 있습니다.");

# lost files (attachment.php)
define("_LOST_FILES","오류파일 정리");
define("_LOST_FILES_DESC","시스템에 첨부파일이 존재하지만 게시물이 없어졌거나, 게시물에 첨부된 파일이 시스템에 존재하지 않는 오류 파일들을 정리합니다.");
define("_LOST_FILES1","파일 시스템상에 존재하지 않는 파일");
define("_LOST_FILES2","시스템에 존재 하지만 첨부되지 않은 파일");
define("_LOST_FILES_DEL","삭제 하기");
?>

==> korweblog-1.6.0.tar.gz: korweblog-1.6.0/admin/lang/utf8.php <==
<?
define("_TOP5_DESC","가장 많이 읽은 글 5개");
define("_HOT5_DESC","가장 답장이 많은 글 5개");
define("_LASTC5_DESC","마지막으로 답장이 붙은글 5개");
define("_STORY_EXT","본문 관련 링크 설정");
define("_STORY_LINK_INDEX","본문 관련 링크 인덱스");
define("_STORY_LINK_INDEX_ADD","인덱스 추가하기");
define("_STORY_LINK_INDEX_KILL","인덱스를 지우면 해당 본문의 관련 링크도 삭제 됩니다.");

define("_LINK_ANYONE","링크 등록 가능 (관리자 확인필요)");
define("_LINK_ONLYADMIN","관리자만 등록 가능");
define("_LINK_FREE","사용자가 자유롭게 링크 등록 가능");
# logs.php
define("_LOGS_NOTHING","내용이 없습니다");
define("_LOGS_RESET","내용 비우기");

# layout.php
define("_LAYOUT_EDITOR","레이아웃 편집기: ");
define("_LAYOUT_VIEW","보기/읽기");
define("_LAYOUT_KILL","삭제");
define("_LAYOUT_ADD","추가/수정");
define("_LAYOUT_AUTHOR","작성자");
define("_LAYOUT_DESC","설명");
define("_LAYOUT_BG","백그라운드 이미지");
define("_LAYOUT_LOGO","로고 이미지");
define("_LAYOUT_FONT","폰트 설정");
define("_LAYOUT_WIDTH","페이지 폭");

define("_LAYOUT_TITLE_COLOR","본문 제목");
define("_LAYOUT_BLOCK_WIDTH","블럭 폭");
define("_LAYOUT_BLOCK_ALIGN","기본 블럭 정렬");
define("_LAYOUT_THEME","테마 / 템플레이트");
define("_LAYOUT_B_LEFT","왼쪽 블럭");
define("_LAYOUT_B_RIGHT","오른쪽 블럭");
define("_LAYOUT_ADDED","레이아웃 파일이 수정되었습니다.");
define("_NOTKILL","삭제하려는 테마가 현재 기본테마로 설정되어 있으므로 삭제할수 없습니다.");

# for Log Messages
define("_UPDATE_STORY","본문 수정");
define("_REPOST_STORY","본문 재등록");
define("_UPDATE_BLOCK","블럭 수정");
define("_UPDATE_REPLY","답장 수정");
define("_UPDATE_TOPIC","분류 수정");
define("_ADD_TOPIC","새분류 생성");
define("_ADD_POLL","투표 생성");
define("_ADD_BLOCK","블럭 추가");
define("_UPDATE_POLL","투표 수정");
define("_UPDATE_CATE","링크 분류 수정");
define("_LOG_RESET","로그 지움");
define("_UPDATE_LAYOUT","레이아웃 수정");
define("_DELETE_LAYOUT","레이아웃 삭제");
define("_UPDATE_SITE","사이트 기본 설정 수정");
define("_UPDATE_STORY_CONF","본문 설정 수정");
define("_UPDATE_REPLY_CONF","답장 설정 수정");
define("_UPDATE_EXT_CONF","확장 기능 수정");
define("_DELETE_ITEM","삭제");
define("_UNABLE_DEL","삭제시 에러 발생");
define("_DEL_POLL","투표 삭제");
define("_DEL_TOPIC","분류 삭제");
define("_DEL_CATE","링크 분류 삭제");

# for Additional Control Page
define("_SHOW_PTIME","페이지 처리 시간 표시");
define("_SHOW_NUM","각 분류의 글갯수 표시");
define("_CATCH_REPLY","모든 답장을 관리자가 이메일로 받아보기");
define("_FORM_WRAP","입력폼의 WRAP 설정");
define("_QP_ENCODE","발송되는 메일의 본문을 자체 QP 인코딩함");
define("_USE_THEME","사용자 테마 블럭");
define("_THEMES","사용자가 고를수 있는 테마 선택");
define("_ANTI_SPAM","스팸 방지 기능");
define("_ANTI_SPAM2","글쓰기 제한 IP");
define("_ANTI_IP","접근 제한 IP");
define("_BLOCK_IP_LIST","접근 제한 IP 목록");
define("_SPAM_LIST","스팸 문자열 목록 (regex)");
define("_BLOCK_LIST","글쓰기 제한 IP 목록");
define("_SHOW_CONTACT","연락처 링크 표시");
define("_CONT_ADD_TXT","글 올리기 페이지에 보여줄 글 (html 가능)");
define("_LOGIN_AD_TXT","익명 사용자의 로그인 박스에 표시될 글 (html 가능)");
define("_TOTAL_COUNT_IN_TOPIC","분류 블럭에 전체 본문,답장수 표시");
define("_REPLY_HTML_PARSE_LEVEL","답장의 html 파싱 레벨");
define("_REPLY_PAGES","답장 표시때 페이지로 나눔");
define("_FILE_CACHE","RDF,URL,INCLUDE 등의 캐쉬를 파일로 처리");
define("_SHOW_IP","본문/답장에 글쓴이 IP 주소를 표시");
define("_ENABLE_BUTTON","본문 하단에 다음/이전글 링크 표시");
define("_ENABLE_DAY","이전글 블럭에 요일/날짜 표시");
define("_REREPLY","답장을 부모 답장의 글쓴이에게 메일로 보내기");
define("_FEATURE_TITLE","특집기사 블럭의 제목");
define("_UC_SCORE","로그인 사용자가 점수 조절 가능(답장 작성시)");
define("_RSS_POPWINDOW","rss 블럭의 링크 클릭시 새창으로 열기");

# topics.php
define("_TOPIC_IMAGE","이미지");
define("_TOPIC_TITLE","제목");
define("_TOPIC_ALTTAG","ALT 태그");
define("_TOPIC_RULE","제한");
define("_TOPIC_KILL","분류가 삭제되면 관련 본문 / 답장도 삭제 됩니다.");
define("_TOPIC_ADD","새 분류 추가");
define("_TOPIC_IMG_NULL","비어있으면 사용하지 않습니다.");
define("_TOPIC_NO_POST","글 올리기 불가");
define("_TOPIC_NO_COMMENT","답장 불가");

# http referer
define("_REFER_LIMIT","기록 제한");
define("_REFER_LIMIT_NO","무제한");
define("_SHOW_ALL","모두 보기");

# browser, os recored
define("_COUNTER","브라우저/OS 기록 (통계)");
define("_TIME_COUNTER","시간별 접속 통계");
define("_COUNT_INIT","초기화 하기");

# menu block
define("_MENU_BLOCK","주 메뉴 블럭 위치");

# session
define("_SESSION","세션 사용 (온라인 접속자 확인 기능)");
define("_SESSION_TMOUT","<font size=\"-1\">시스템을 다음 시간동안 사용하지 않으면 접속하지 않은 것으로 판단: ");
define("_SESSION_MIN","분</font>");
define("_ONLY_SESSION","(<a href=\"user-ext.php\">세션 사용</a>이 켜져 있을 경우에만 작동합니다.)");

# private msg
define("_PRIVATE_MSG","사용자 개인 쪽지");
define("_PRIV_MSG_LIMIT","최대 쪽지 수 제한");

# user
define("_LEVEL","권한");
define("_NORMAL_USER","일반 사용자");
define("_MODERATOR","중재자");
define("_SCORE_MODERATOR","점수 중재자");
define("_TOTAL","전체");
define("_USER_ADMIN","사용자 관리");
define("_USER_ADD","등록");
define("_USER_FIND","찾기");
define("_USER_EDIT","수정");
define("_USER_KILL","삭제");
define("_SENDMAIL","등록후 사용자에게 이메일 보냄");
define("_UPDATED_USERDB","사용자 정보를 변경 했습니다.");
define("_USER_ADDED","사용자를 등록 했습니다.");
define("_USER_DELETED","사용자를 삭제 했습니다.");

# submit log
define("_UPDATED","수정됨");

define("_MORECONFIG","추가");

# user-ext
define("_ONLINE_USER_INFO_DISPLAY","온라인 사용자 정보 표시");
define("_STORY_WATCH","답장 감시 기능");
define("_REGIST_METHOD","사용자 등록시 이메일 주소 유효성 확인");
define("_USER_IMG","사용자 홈의 이미지");
define("_COOKIE_TIME","사용자 로그인 쿠키 유효 기간");
define("_DAY","일");

define("_STORY_WATING","예약된 글");
define("_NO_PROGRAM_STORY","프로그램된 글이 없습니다.");
define("_AUTO_STORY","예약 포스팅");
define("_STORY_PROGRAM","이 글을 지정된 시간에 포스팅");
define("_PROGRAM_SAVED","성공적으로 저장 되었습니다.");
define("_CURRENT_TIME","현재 시간");
define("_YEAR","년");
define("_UMONTH","월");
define("_HOUR","시");
define("_MINUTE","분");
define("_POSTING_TIME","예약 시간");
define("_STORY_PROGRAM_EDITED","변경 사항이 저장 되었습니다.");
define("_STORY_PROGRAM_DELETED","글을 삭제 했습니다.");

define("_BMARK_LIMIT","책갈피 갯수 제한");

# admin_msg.php
define("_ADMIN_MSG","관리자 알림 메세지");
define("_ADMIN_MSG_EDIT","수정");
define("_ADMIN_MSG_ADD","추가");
define("_DISPLAY","표시 여부");
define("_ACTIVE","표시");
define("_INACTIVE","끔");
define("_DISPLAY_TYPE","표시 방법");
define("_EXPIRE","만기");
define("_CONTENT","내용");

define("_COPYRIGHT","저작권");
define("_NOLOGIN_USER","로그인 사용자 기능 사용하지 않음");

# sql.php
define("_PHP_INFO","PHP 정보 보기");
define("_SQL_RUNTIME","런타임 정보 보기");
define("_SQL_SYSTEM_VAR","시스템 변수 보기");
define("_SQL_PROCESS","프로세스 보기");
define("_SQL_CHECK_TABLE","테이블 확인");
define("_SQL_REPAIR_TABLE","테이블 복구");
define("_SQL_OPTIMIZE_TABLE","테이블 옵티마이즈");
define("_SQL_BACKUP_TABLE","데이터베이스 백업");
define("_SQL_DOCUMENT","도움말");
define("_SQL_ADMIN","데이터베이스 관리");

# navigator.php
define("_NAVIGATOR","메뉴 설정");
define("_NAVIG_TOP","상단 링크");
define("_NAVIG_BLOCK","주 메뉴 블럭");
define("_NAVIG_MOVE","이동");
define("_NAVIG_NAME","링크");
define("_NAVIG_ORDER","정렬");
define("_NAVIG_ADD","외부 링크 추가");
define("_NAVIG_EDIT","외부 링크 수정");
define("_NAVIG_DISPLAY_NAME","링크 이름");
define("_NAVIG_URL","Url");

# faq.php
define("_NEW_FAQ","새 FAQ 만들기");
define("_FAQ_TITLE","FAQ 제목");
define("_ADD_QA","질문/답변 추가하기");
define("_EDIT_QA","질문/답변 수정하기");
define("_EDIT_FAQ","FAQ 제목 수정");

# htmltag.php
define("_HTML_OPTION","HTML 태그 설정");
define("_HTML_OPTION1","최소한 한개 이상의 태그를 선택해야 합니다.");

# config-story.php
define("_HTML_PARSE_LEVEL","기본 HTML 파싱 레벨");
define("_RDF_USE","RDF 파일 사용 여부");
define("_MAILING_USE","메일링 리스트 사용");
define("_USER_PARSE","사용자가 파싱 레벨 결정");
define("_EXPORT_RDF_NOW","RSS 파일 다시 만들기");
define("_EXPORT_RDF_NOW1","RSS 파일을 만들었습니다.");
define("_THUMBNAIL","썸네일 만들기");
define("_IMAGICK","Imagick 프로그램의 완전한 경로 (보통 /usr/bin/convert)");
define("_MAX_PIC_PIXEL","첨부된 이미지 파일(jpg,gif,png)의 크기가 다음에 지정한 넓이 또는 높이(픽셀 단위) 보다 크면 썸네일을 만듭니다.");
define("_THUMB_SIZE","썸네일의 크기를 지정 합니다 (넓이, 픽셀 단위)");
define("_NO_IMAGICK","convert 실행 파일을 찾을 수 없습니다!");

# polls.php
define("_POLL_QUES","질문");
define("_POLL_ADD","투표 추가하기");
define("_POLL_DISP","표시 위치");
define("_POLL_EXPIRE","쿠키 만료일");
define("_POLL_ANSWER","답변");

# random_link.php
define("_RANDOM_LINK_ADD","링크 추가");
define("_RANDOM_LINK_EDIT","링크 수정");
define("_RANDOM_LINK_TITLE","링크 이름");
define("_RANDOM_LINK_NUMS","한번에 표시할 링크 갯수");
define("_RANDOM_LINK_HEAD","랜덤 링크 블럭 제목");
define("_RANDOM_LINK_SOURCE","링크 소스");
define("_RLINK_PREF1","직접 입력");
define("_RLINK_PREF2","링크 페이지에서");
define("_RLINK_PREF3","본문 관련 링크에서");

# random_button.php
define("_RANDOM_BUTTON_ADD","버튼 추가");
define("_RANDOM_BUTTON_EDIT","버튼 수정");
define("_RANDOM_BUTTON_ALT","Alt 문자");
define("_RANDOM_BUTTON_NUMS","한번에 표시할 버튼 갯수");
define("_RANDOM_BUTTON_HEAD","랜덤 버튼 블럭 제목");

# banners.php
define("_BANNER","배너");
define("_BANNER_LOCATION","배너 표시 위치");
define("_BANNER_LOCATION_DESC","각 테마 템플레이트 파일의 \"header.tmpl\", 또는 \"footer.tmpl\" 파일에 \"\$banner\" 변수를 추가해야 합니다.");
define("_BANNER_ALT","ALT 문자");
define("_BANNER_ADD","배너 추가");
define("_BANNER_EDIT","배너 수정");

# blocks.php
define("_BLOCK_STORY_ONLY","메인 페이지에만 표시");
define("_BLOCK_RDF_SUPP","RSS/RDF 포맷을 지원합니다.");
define("_BLOCK_INCLUDE","URL 또는 PATH");
define("_BLOCK_CACHE","캐쉬 설정");
define("_BLOCK_CACHE_DESC","분 / 0은 캐쉬 안함");
define("_NOT_URL","Url 또는 파일을 읽을 수 없습니다");
define("_MAX_ITEMS","최대 링크 갯수");

# config-site.php
define("_UNIQUEKEY","보안 열쇠");
define("_KEYDESC","Korweblog를 처음 설치했다면 반듯이 수정하여야 합니다.");

# config-new.php
define("_STORY_LST","익명 사용자의 답장 읽기를 제한할 본문 Rid");

# user-mail.php
define("_ALL","전체");
define("_MAIL_SEND","보냄");
define("_GROUP_MAIL","그룹 메일 보내기");
define("_GROUP","사용자 그룹");
define("_SENDMAIL_WARN","사용자가 많은 경우 시간이 많이 소요 될 수 있습니다. \"보냄\" 버튼을 누르시고 다음 화면이 나타날때 까지 기다리셔야 합니다. 버튼을 여러번 누르거나 브라우저를 종료하면 메일 전송에 실패 할 수 있습니다.");

# lost files (attachment.php)
define("_LOST_FILES","오류파일 정리");
define("_LOST_FILES_DESC","시스템에 첨부파일이 존재하지만 게시물이 없어졌거나, 게시물에 첨부된 파일이 시스템에 존재하지 않는 오류 파일들을 정리합니다.");
define("_LOST_FILES1","파일 시스템상에 존재하지 않는 파일");
define("_LOST_FILES2","시스템에 존재 하지만 첨부되지 않은 파일");
define("_LOST_FILES_DEL","삭제 하기");

# trackback msg
define("_TBMSG_LENGTH","트랙백 메시지 길이 제한");
define("_TBMSG_SHOW","트랙백 메시지를 답장과 함께 표시");
?>
